Index: src/test/org/apache/lucene/index/TestSortOrder.java
===================================================================
--- src/test/org/apache/lucene/index/TestSortOrder.java	(revision 0)
+++ src/test/org/apache/lucene/index/TestSortOrder.java	(revision 0)
@@ -0,0 +1,73 @@
+package org.apache.lucene.index;
+
+/**
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+import org.apache.lucene.analysis.KeywordAnalyzer;
+import org.apache.lucene.document.Document;
+import org.apache.lucene.document.Field;
+import org.apache.lucene.store.RAMDirectory;
+import org.apache.lucene.util.LuceneTestCase;
+
+/**
+ * Test TermEnum for some differences between UTF-8/UTF-38 and UTF-16 binary sort order.
+ */
+public class TestSortOrder extends LuceneTestCase {
+  private IndexReader reader;
+
+  private final String FN = "field";
+
+  public void setUp() throws Exception {
+    super.setUp();
+    RAMDirectory directory = new RAMDirectory();
+    IndexWriter writer = new IndexWriter(directory, new KeywordAnalyzer(), true,
+        IndexWriter.MaxFieldLength.LIMITED);
+    Document doc = new Document();
+    Field field = new Field(FN, "", Field.Store.NO,
+        Field.Index.ANALYZED);
+    doc.add(field);
+    field.setValue("\uD866\uDF05abcdef");
+    writer.addDocument(doc);
+    field.setValue("\uD866\uDF06ghijkl");
+    writer.addDocument(doc);
+    field.setValue("\uFB94mnopqr"); // this sorts before the previous two in UTF-8/UTF-32, but after in UTF-16!!!
+    writer.addDocument(doc);
+    field.setValue("\uFB95stuvwx"); // this one too.
+    writer.addDocument(doc);
+    writer.optimize();
+    writer.close();
+    reader = IndexReader.open(directory, true);
+  }
+
+  public void tearDown() throws Exception {
+    reader.close();
+    super.tearDown();
+  }
+
+  public void testTermEnumOrder() throws Exception {
+    TermEnum te = reader.terms();
+    assertTrue(te.next());
+    assertEquals(new Term(FN, "\uD866\uDF05abcdef"), te.term());
+    assertTrue(te.next());
+    assertEquals(new Term(FN, "\uD866\uDF06ghijkl"), te.term());
+    assertTrue(te.next());
+    assertEquals(new Term(FN, "\uFB94mnopqr"), te.term());
+    assertTrue(te.next());
+    assertEquals(new Term(FN, "\uFB95stuvwx"), te.term());
+    assertFalse(te.next());
+  }
+}
\ No newline at end of file

Property changes on: src\test\org\apache\lucene\index\TestSortOrder.java
___________________________________________________________________
Added: svn:eol-style
   + native

